==> flutter_timetable_view-0.0.1.tar.gz: lib/src/views/event_view.dart <==
import 'dart:math' as math;

import 'package:flutter/material.dart';
import 'package:flutter_timetable_view/src/models/table_event.dart';
import 'package:flutter_timetable_view/src/styles/timetable_style.dart';
import 'package:flutter_timetable_view/src/utils/utils.dart';

class EventView extends StatelessWidget {
  final TableEvent event;
  final TimetableStyle timetableStyle;

  const EventView({
    Key key,
    @required this.event,
    @required this.timetableStyle,
  })  : assert(event != null),
        assert(timetableStyle != null),
        super(key: key);

  @override
  Widget build(BuildContext context) {
    return Positioned(
      top: top(),
      height: height(),
      left: 0,
      width: timetableStyle.laneWidth,
      child: GestureDetector(
        onTap: event.onTap,
        child: Container(
          decoration: event.decoration ??
              (event.backgroundColor != null
                  ? BoxDecoration(color: event.backgroundColor)
                  : null),
          margin: event.margin,
          padding: event.padding,
          child: (Utils.eventText)(
            event,
            context,
            math.max(
                0.0,
                height() -
                    (event.padding?.top ?? 0.0) -
                    (event.padding?.bottom ?? 0.0)),
            math.max(
                0.0,
                timetableStyle.laneWidth -
                    (event.padding?.left ?? 0.0) -
                    (event.padding?.right ?? 0.0)),
          ),
        ),
      ),
    );
  }

  double top() {
    return calculateTopOffset(event.start.hour, event.start.minute) -
        timetableStyle.startHour * 60;
  }

  double height() {
    return calculateTopOffset(0, event.end.difference(event.start).inMinutes) +
        1;
  }

  double calculateTopOffset(
    int hour, [
    int minute = 0,
    double hourRowHeight,
  ]) {
    return (hour + (minute / 60)) * (hourRowHeight ?? 60);
  }
}

==> flutter_timetable_view-0.1.0.tar.gz: lib/src/views/event_view.dart <==
import 'dart:math' as math;

import 'package:flutter/material.dart';
import 'package:flutter_timetable_view/src/models/table_event.dart';
import 'package:flutter_timetable_view/src/styles/timetable_style.dart';
import 'package:flutter_timetable_view/src/utils/utils.dart';

class EventView extends StatelessWidget {
  final TableEvent event;
  final TimetableStyle timetableStyle;

  const EventView({
    Key key,
    @required this.event,
    @required this.timetableStyle,
  })  : assert(event != null),
        assert(timetableStyle != null),
        super(key: key);

  @override
  Widget build(BuildContext context) {
    return Positioned(
      top: top(),
      height: height(),
      left: 0,
      width: timetableStyle.laneWidth,
      child: GestureDetector(
        onTap: event.onTap,
        child: Container(
          decoration: event.decoration ??
              (event.backgroundColor != null
                  ? BoxDecoration(color: event.backgroundColor)
                  : null),
          margin: event.margin,
          padding: event.padding,
          child: (Utils.eventText)(
            event,
            context,
            math.max(
                0.0,
                height() -
                    (event.padding?.top ?? 0.0) -
                    (event.padding?.bottom ?? 0.0)),
            math.max(
                0.0,
                timetableStyle.laneWidth -
                    (event.padding?.left ?? 0.0) -
                    (event.padding?.right ?? 0.0)),
          ),
        ),
      ),
    );
  }

  double top() {
    return calculateTopOffset(event.start.hour, event.start.minute,
            timetableStyle.timeItemHeight) -
        timetableStyle.startHour * timetableStyle.timeItemHeight;
  }

  double height() {
    return calculateTopOffset(0, event.end.difference(event.start).inMinutes,
            timetableStyle.timeItemHeight) +
        1;
  }

  double calculateTopOffset(
    int hour, [
    int minute = 0,
    double hourRowHeight,
  ]) {
    return (hour + (minute / 60)) * (hourRowHeight ?? 60);
  }
}
